timeintervaltools.get_all_unique_bounds_in_intervals
====================================================

.. autofunction:: abjad.tools.timeintervaltools.get_all_unique_bounds_in_intervals.get_all_unique_bounds_in_intervals
